@@ -24,7 +24,7 @@ default_options = {
             "location": ".joblib.memory",
         },
     },
-    "tqdm": {"disable": False, "delay": 1},
+    "tqdm": {"disable": False, "delay": 0.2},
     "serialization": {
         "enable_compression": False,
         "store_pickle": False,
